@@ -1,7 +1,7 @@
 import glpk
 
 print "starting..."
-example = glpk.lpx("example.mod")
+example = glpk.glpk("example.mod")
 example.solve()
 print "solution:", example.sol
 print "solution is also here:", example.x
